package com.ruoyi.system.service.impl;

import com.ruoyi.common.core.domain.entity.Tag;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.mapper.TagMapper;
import com.ruoyi.system.service.ITagService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 【请填写功能名称】Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-07-22
 */
@Service
public class TagServiceImpl implements ITagService 
{
    @Autowired
    private TagMapper tagMapper;

    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public Tag selectTagById(String id)
    {
        return tagMapper.selectTagById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param tag 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<Tag> selectTagList(Tag tag)
    {
        return tagMapper.selectTagList(tag);
    }

    /**
     * 新增【请填写功能名称】
     * 
     * @param tag 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertTag(Tag tag)
    {
        tag.setCreateTime(DateUtils.getNowDate());
        return tagMapper.insertTag(tag);
    }

    /**
     * 修改【请填写功能名称】
     * 
     * @param tag 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateTag(Tag tag)
    {
        return tagMapper.updateTag(tag);
    }

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteTagByIds(String[] ids)
    {
        return tagMapper.deleteTagByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteTagById(String id)
    {
        return tagMapper.deleteTagById(id);
    }
}
